stkhelper - for easy python integration with STK

Purpose:
    This package was created as a bridge between a user and the STK Interface.
    The stkhelper package allows you to easily make scenarios and add
    satellites and area targets.
    
Usage:
    To use stkhelper, you must have a license for STK that is above the free
    beginner license and allows for integration. As it stands, the package only
    works on Windows, but will hopefully work on Mac OS in the future.
